declare enum JoliboxRuntimeEvents {
    /**
     * Event dispatched when the loading starts
     */
    LOAD_START = "JOLIBOX_RUNTIME_LOAD_START",
    /**
     * Event dispatched when the loading is finished
     */
    LOAD_FINISHED = "JOLIBOX_RUNTIME_LOAD_FINISHED",
    /**
     * Event dispatched when the loading progress is updated
     */
    LOAD_PROGRESS = "JOLIBOX_RUNTIME_LOAD_PROGRESS"
}
/**
 * Jolibox Runtime, a set of utilities to interact with the Jolibox runtime
 * @class
 */
declare class JoliboxRuntime {
    /**
     * Notify the end of the loading, will close the loading splash screen
     */
    loadFinished: () => void;
    /**
     * Notify the progress of the loading, will update the loading splash screen
     * @param progress - The progress of the loading, should be an integer between 0 and 100
     */
    notifyLoadProgress: (progress: number) => void;
}

interface IHttpClientInitParams {
    baseUrl?: string;
}
declare class JoliboxHttpClient {
    private baseUrl;
    private xua;
    private getGameId;
    private getJoliSource;
    constructor(config?: IHttpClientInitParams);
    get<T>(path: string, { query, headers, timeout, }: {
        query?: Record<string, string>;
        headers?: Record<string, string>;
        timeout?: number;
    }): Promise<T>;
    post<T = any>(path: string, { data, query, headers, timeout, }: {
        data?: any;
        query?: Record<string, string>;
        headers?: Record<string, string>;
        timeout?: number;
    }): Promise<T>;
    put<T>(path: string, { data, query, headers, }: {
        data?: any;
        query?: Record<string, string>;
        headers?: Record<string, string>;
        timeout?: number;
    }): Promise<T>;
}

declare global {
    interface Window {
        JoliboxCloudStorage: typeof JoliboxCloudStorage;
    }
}
type ResponseCode = "SUCCESS" | "UNAUTHORIZED" | "NOT_FOUND" | "PARAMETER_ERROR" | "EXCEED_MAXIMUM_KEY_LIMIT" | "INTERNAL_ERR";
/**
 * Cloud storage response
 */
interface StorageResponse<T> {
    /**
     * Response code
     * It will be one of the following values:
     * - SUCCESS, if the operation is successful
     * - UNAUTHORIZED, if the user is not logged in
     * - NOT_FOUND, if the key is not found
     * - PARAMETER_ERROR, if the key length > 128 or value length > 1024
     * - EXCEED_MAXIMUM_KEY_LIMIT, if exceed the maximum key limit
     * - INTERNAL_ERR, if some other internal error
     */
    code: ResponseCode;
    /**
     * Response message, error message or success message
     */
    message: string;
    /**
     * Response data, the data you want to get or set
     */
    data?: T;
}
type VALID_SET_TYPE = string | number | boolean;
/**
 * Jolibox Cloud Storage, a set of utilities to set storage data into cloud and localstorage
 * This class will use cloud storage as the primary storage, and fallback to localstorage if cloud storage is not available
 * All the mutation to the cloud storage requires login status, if not logged in, the mutation will only be done in localstorage
 */
declare class JoliboxCloudStorage {
    private gameId;
    private httpClient;
    private gameStore;
    constructor();
    /**
     *  Cloud storage getItem api
     */
    private getGameId;
    /**
     * Cloud storage getItem api
     * Will try to get data from cloud first, if failed, will read from localstorage
     * @param key getItem key
     */
    getItem: (key: string) => Promise<StorageResponse<string | null>>;
    /**
     * Cloud storage setItem api
     * Will set data to cloud and localstorage
     * If the key already exists, the value will be updated, otherwise a new key-value pair will be created
     * @param key setItem key
     * @param value setItem value
     */
    setItem: (key: string, value: VALID_SET_TYPE) => Promise<StorageResponse<{}>>;
    /**
     * Cloud storage removeItem api
     * Will remove data from cloud and localstorage
     * @param key
     * @returns
     */
    removeItem: (key: string) => Promise<StorageResponse<string>>;
    /**
     * Cloud storage clear api
     * Will clear all data from cloud and localstorage
     * @returns
     */
    clear: () => Promise<StorageResponse<string>>;
    private isPrimitiveType;
}

declare const platform: {
    isiOS: boolean;
    iosVersion: () => number[];
    isAndroid: boolean;
    isMac: boolean;
    isFacebook: boolean;
    isPC: boolean;
};
declare const getPlatform: () => "Android" | "Mac" | "iOS" | "Facebook" | "PC";
declare const getAppVersion: () => string;
declare const DEVICE_ID = "device_id";
declare const ADVERTISING_ID = "advertising_id";
declare const getStorage: (cookieKey: string) => string;
declare const getDeviceId: () => string;
declare const getAdvertisingId: () => string;
declare const getUtmSource: () => string;
declare const xUserAgent: () => string;

declare const xua_ADVERTISING_ID: typeof ADVERTISING_ID;
declare const xua_DEVICE_ID: typeof DEVICE_ID;
declare const xua_getAdvertisingId: typeof getAdvertisingId;
declare const xua_getAppVersion: typeof getAppVersion;
declare const xua_getDeviceId: typeof getDeviceId;
declare const xua_getPlatform: typeof getPlatform;
declare const xua_getStorage: typeof getStorage;
declare const xua_getUtmSource: typeof getUtmSource;
declare const xua_platform: typeof platform;
declare const xua_xUserAgent: typeof xUserAgent;
declare namespace xua {
  export { xua_ADVERTISING_ID as ADVERTISING_ID, xua_DEVICE_ID as DEVICE_ID, xua_getAdvertisingId as getAdvertisingId, xua_getAppVersion as getAppVersion, xua_getDeviceId as getDeviceId, xua_getPlatform as getPlatform, xua_getStorage as getStorage, xua_getUtmSource as getUtmSource, xua_platform as platform, xua_xUserAgent as xUserAgent };
}

declare const getGameSessionId: () => string;

declare const session_getGameSessionId: typeof getGameSessionId;
declare namespace session {
  export { session_getGameSessionId as getGameSessionId };
}

declare const uuidv4: () => string;
declare const isValidUUIDV4: (uuid: string) => boolean;

declare const uuid_isValidUUIDV4: typeof isValidUUIDV4;
declare const uuid_uuidv4: typeof uuidv4;
declare namespace uuid {
  export { uuid_isValidUUIDV4 as isValidUUIDV4, uuid_uuidv4 as uuidv4 };
}

declare global {
    interface Window {
        JoliboxUtil: typeof JoliboxUtil;
    }
}
declare class JoliboxUtil {
    static xua: typeof xua;
    static session: typeof session;
    static uuid: typeof uuid;
}

interface ICommandPipe {
    cmd: string;
    params: any;
}
declare global {
    interface IJoliboxSDK {
        _commandPipe: ICommandPipe[];
    }
    interface Window {
        joliboxsdk: IJoliboxSDK;
        JoliboxRuntime: typeof JoliboxRuntime;
        JoliboxRuntimeEvents: typeof JoliboxRuntimeEvents;
        JoliboxHttpClient: typeof JoliboxHttpClient;
        JoliboxCloudStorage: typeof JoliboxCloudStorage;
        JoliTesterBridge?: any;
        __JOLIBOX_LOCAL_SDK_VERSION__: string;
        joliboxenv?: {
            joliboxEnv: "staging" | "production";
            testAdsMode: boolean;
            apiBaseURL: string;
        };
    }
}

export { JoliboxCloudStorage, JoliboxHttpClient, JoliboxRuntime, JoliboxRuntimeEvents, JoliboxUtil, type ResponseCode, type StorageResponse };
